unit main;

interface

uses
{$IFDEF WIN32}
  Windows, ComCtrls,
{$ELSE}
  WinTypes, WinProcs,
{$ENDIF}
  Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ExtCtrls, Segment, Compress, Menus;

type
  TMainForm = class(TForm)
    CmdGroup: TRadioGroup;
    LBGroup: TGroupBox;
    LB: TListBox;
    Panel1: TPanel;
    SelectBtn: TBitBtn;
    ResetBtn: TBitBtn;
    HdrBtn: TBitBtn;
    ExecuteBtn: TBitBtn;
    TheCnt: TLabel;
    EMultiArc: TCheckBox;
    SetupBtn: TBitBtn;
    SegCompEZ: TSegCompEZ;
    MsgPanel: TPanel;
    StatPanel: TPanel;
    procedure FormCreate(Sender: TObject);
    procedure ResetBtnClick(Sender: TObject);
    procedure CmdGroupClick(Sender: TObject);
    procedure HdrBtnClick(Sender: TObject);
    procedure ExecuteBtnClick(Sender: TObject);
    procedure SelectBtnClick(Sender: TObject);
    procedure SetupBtnClick(Sender: TObject);
    procedure EMultiArcClick(Sender: TObject);
    procedure BeforeExpand(var SegArcList: TSegArcList);
    procedure LBDblClick(Sender: TObject);
    procedure DoCheckFile(var filepath: OpenString; mode: TCProcessMode);
  private
    { Private declarations }
    procedure  SetMessage( const Msg: String );
    procedure  SetStatus( const Msg: String );
    procedure  TheCount;
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

uses  Common, SelFiles, SelArcs, SegSet, SegHdr, SegArc, Target, Modify;

{$R *.DFM}
{===============================================================}
{===============================================================}
procedure TMainForm.FormCreate(Sender: TObject);
begin
     SegCompEZ.SegArcList.RemoveAll;
     ResetBtnClick(Sender);
end;

{===============================================================}
{===============================================================}
procedure TMainForm.SetMessage( const Msg: String );
begin
     MsgPanel.Caption := Msg;
     MsgPanel.Update;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.SetStatus( const Msg: String );
begin
     StatPanel.Caption := Msg;
     StatPanel.Update;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.TheCount;
begin
     TheCnt.Caption := 'Count: ' + IntToStr(LB.Items.Count);
     TheCnt.Update;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.CmdGroupClick(Sender: TObject);
begin
     {Compress}
     if ( CmdGroup.ItemIndex = 0) then
       ResetBtnClick(Sender)
     {Expand & Scan}
     else
       begin
       LB.Clear;
       EMultiArc.State := cbUnChecked;
       SegCompEZ.SegMultiArc := False;
       EMultiArc.Enabled := False;
       HdrBtn.Enabled := False;
       SelectBtn.Enabled := False;
       ExecuteBtn.Enabled := True;
       end;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.SelectBtnClick(Sender: TObject);
var
   i:          Integer;
   SL:         TStringList;
   SArc:       TSegArc;
   SArcList:   TSegArcList;
   FName:      String;
   Template:   String;
   Target:     String;
begin
    LB.Clear;
    TheCount;
    LBGroup.Caption := '';
    SegCompEZ.SegSource.Clear;
    SL := TStringList.Create;

    {==========================================================}
    { This section allows you to compress one or more files    }
    { that reside on the same drive.  After the selection is   }
    { complete, the LB listbox is updated with the file names. }
    { This method will create a single archive within the      }
    { segment set.                                             }
    { Note:  The actual execution is done in ExecuteBtnClick   }
    {==========================================================}
    if (EMultiArc.State = cbUnChecked) then
      begin
      Target := '';
      SelFilesForm.SelectFiles( Target, SL );
      LB.OnDblClick := nil;
      if (SL.Count > 0) then
        begin
        LBGroup.Caption := Target;
        SegCompEZ.TargetPath := Target;
       end;
      end

    {==========================================================}
    { This section allows you to compress multiple archives    }
    { into a single segment set.  The idea is that you may     }
    { want to have file from multiple drives in the same       }
    { segment set. For example, if you wanted to backup the    }
    { files in c:\myfiles\*.* and d:\mydata\*.*, you would use }
    { the 'multi-archive' method.  This will store each group  }
    { as a seperate archive within the segment set.            }
    { Note:  The actual execution is done in ExecuteBtnClick   }
    {==========================================================}
    else if (EMultiArc.State = cbChecked) then
      begin
      LB.OnDblClick := nil;
      SelArcsForm.SelectArcs(SL);
      SegCompEZ.TargetPath := '';
      end;

   for i := 0 to SL.Count-1 do
     begin
     LB.Items.Add(SL[i]);
     SegCompEZ.SegSource.Add(Target + SL[i]);
     end;

    SL.Free;
    TheCount;
    if (LB.Items.Count > 0) then
      ExecuteBtn.Enabled := True;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.EMultiArcClick(Sender: TObject);
begin
     if (EMultiArc.State = cbChecked) then
       SegCompEZ.SegMultiArc := True
     else
       SegCompEZ.SegMultiArc := False;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.SetupBtnClick(Sender: TObject);
begin
     SetupForm.Execute;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.HdrBtnClick(Sender: TObject);
begin
     SegHdrForm.EntryPoint( SegCompEZ.SegHeader );
end;

{===============================================================}
{===============================================================}
procedure TMainForm.ResetBtnClick(Sender: TObject);
begin
     HdrBtn.Enabled := False;
     SelectBtn.Enabled := True;
     CmdGroup.ItemIndex := 0;
     EMultiArc.Enabled := True;
     if (SegCompEZ.SegMultiArc) then
       EMultiArc.State := cbChecked
     else
       EMultiArc.State := cbUnChecked;
     LBGroup.Caption := '';
     LB.Clear;
     LB.OnDblClick := nil;
     TheCount;
     SegCompEZ.SegArcList.RemoveAll;
     ExecuteBtn.Enabled := False;
     SetMessage('Select Command and Option');
     SetStatus('Ready');
end;

{===============================================================}
{===============================================================}
procedure TMainForm.ExecuteBtnClick(Sender: TObject);
var
   i:      Integer;
begin
     {Compress}
     if (CmdGroup.ItemIndex = 0) then
       begin
       try
         SetMessage('Compressing...');
         SetStatus('Busy');
         Screen.Cursor := crHourGlass;
         LB.Clear;
    {==========================================================}
    { This assumes that the SegCompEZ properties are already   }
    { set up.                                                  }
    {==========================================================}
        SegCompEZ.Compress;

       except
         SetMessage('Compress operation failed! Press Reset');
         SetStatus('Ready');
         ExecuteBtn.Enabled := False;
         Screen.Cursor := crDefault;
         exit;
       end; {try}

       SetMessage('Done!');
       SetStatus('Ready');
       Screen.Cursor := crDefault;
       end

     {Expand}
     else if (CmdGroup.ItemIndex = 1) then
       begin
       try
         SetMessage('Expanding...');
         SetStatus('Busy');
         Screen.Cursor := crHourGlass;
         LB.Clear;

    {==========================================================}
    { This assumes that the SegCompEZ properties are already   }
    { set up. The OnSegBefore event is used to allow you to    }
    { modify the file list before the expand is really done.   }
    {==========================================================}
        SegCompEZ.Expand;
        HdrBtn.Enabled := True;
        SetMessage('Done!');

       except
         SetMessage('Expand operation failed! Press Reset');
         ExecuteBtn.Enabled := False;
       end; {try}
       end

     {Scan}
     else
       begin
       try
         SetMessage('Scanning...');
         SetStatus('Busy');
         Screen.Cursor := crHourGlass;
         LB.Clear;
         LB.OnDblClick := LBDblClick;

    {==========================================================}
    { This assumes that the SegCompEZ properties are already   }
    { set up.                                                  }
    {==========================================================}
         SegCompEZ.Scan;

         for i := 0 to SegCompEZ.SegSource.Count-1 do
           LB.Items.Add(SegCompEZ.SegSource[i]);
         HdrBtn.Enabled := True;
         LBGroup.Caption := '';
         SetMessage('Done!');
       except
         SetMessage('Scan operation failed! Press Reset');
         ExecuteBtn.Enabled := False;
       end; {try}
       ShowMessage('Double Click on any item for details');
     end; {Scan}

     TheCount;
     SetStatus('Ready');
     Screen.Cursor := crDefault;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.DoCheckFile(var filepath: OpenString;
  mode: TCProcessMode);
begin
     if (SegCompEZ.SegMultiArc) then
       LB.Items.Add(SegCompEZ.TargetPath+filepath)
     else
       LB.Items.Add(filepath);
     LB.Update;
     TheCount;
     SetMessage(filepath);

end;


{===============================================================}
{===============================================================}
procedure TMainForm.BeforeExpand(var SegArcList: TSegArcList);
var
    i:            Integer;
    SArc:         TSegArc;
begin
     for i := 0 to SegArcList.Count-1 do
       begin
       SArc := TSegArc(SegArcList.Items[i]);
       SegCompEZ.SegSource.Add(SArc.Template);
       end;

     if (MessageDlg('Do you want to modify expand options?',mtInformation,
                    [mbYes,mbNo],0) = mrYes) then
       begin
       ModForm.EntryPoint;
       end;
end;

{===============================================================}
{===============================================================}
procedure TMainForm.LBDblClick(Sender: TObject);
var
  SArc:    TSegArc;
begin
     if (CmdGroup.ItemIndex = 2) then
       begin
       SArc := TSegArc(SegCompEZ.SegArcList.Lookup(LB.Items[LB.ItemIndex]));
       SegArcForm.ViewEntry(SArc);
       end;
end;

end.
